@@ -1,4 +1,4 @@
-import gtk, pygtk, os,sys,time,math,hildon,hildondesktop,dbus,gobject
+import gtk, pygtk, os,sys,time,math,hildon,hildondesktop,dbus,gobject,random
 import dbus.service
 import dbus.mainloop.glib
 from dbus.mainloop.glib import DBusGMainLoop
@@ -11,25 +11,19 @@ blinker_stat=0
 mem6_stat=False
 mem7_stat=False
 mem8_stat=True
+pxs=0
 def led(event):
 	stat=int(os.popen("/opt/lfocus/v4l2-ctl -C torch_intensity|awk '{print $2}'").read())
 	os.popen("/opt/lfocus/v4l2-ctl -c torch_intensity="+str(int(not(stat))))
 def rled(event):
 	stat=int(os.popen("/opt/lfocus/v4l2-ctl -C indicator_intensity|awk '{print $2}'").read())
 	os.popen("/opt/lfocus/v4l2-ctl -c indicator_intensity="+str(int(not(stat))*3))
-
-
-
 class lfocus_object(dbus.service.Object):
 	def __init__(self, conn, object_path='/com/nokia/lfocus_comms/lfocus_service/object'):
 		dbus.service.Object.__init__(self, conn, object_path)
 	@dbus.service.signal('com.nokia.lfocus_comms.lfocus_service')
 	def lfocus_signal(self, message):
 		pass
-
-
-
-
 	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
 	def lfocus_led1(self):
 		self.lfocus_signal('L1')
@@ -42,11 +36,6 @@ class lfocus_object(dbus.service.Object):
 	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
 	def lfocus_rled0(self):
 		self.lfocus_signal('RL0')
-
-
-
-
-
 	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
 	def lfocus_led1_r(self):
 		self.lfocus_signal('L1_R')
@@ -59,11 +48,6 @@ class lfocus_object(dbus.service.Object):
 	@dbus.service.method('com.nokia.lfocus_comms.lfocus_service')
 	def lfocus_rled0_r(self):
 		self.lfocus_signal('RL0_R')
-
-
-
-
-
 	@dbus.service.method("com.nokia.lfocus_comms.lfocus_service", in_signature='', out_signature='')
 	def Exit(self):
 		loop.quit()
@@ -71,14 +55,11 @@ dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
 System_bus = dbus.SystemBus()
 name = dbus.service.BusName('com.nokia.lfocus_comms.lfocus_service', System_bus)
 object = lfocus_object(System_bus)
-
-
 class lfocusplug(hildondesktop.StatusMenuItem):
 	def __init__(self):
 		hildondesktop.StatusMenuItem.__init__(self)
 		dbus_loop = DBusGMainLoop()
 		self.bus = dbus.SystemBus(mainloop=dbus_loop)
-		
 		self.shutter_button_obj = self.bus.get_object("org.freedesktop.Hal",	"/org/freedesktop/Hal/devices/platform_cam_shutter")
 		self.shutter_button_iface = dbus.Interface(self.shutter_button_obj, 	"org.freedesktop.Hal.Device")
 		self.bus.add_signal_receiver(	self.shutter_operaion, 
@@ -86,46 +67,40 @@ class lfocusplug(hildondesktop.StatusMenuItem):
 						dbus_interface=				"org.freedesktop.Hal.Device", 
 						bus_name=				"org.freedesktop.Hal", 
 						path=					"/org/freedesktop/Hal/devices/platform_cam_shutter")
-
 		self.bus.add_signal_receiver(	self.signal_filter,
 						dbus_interface = 			"com.nokia.lfocus_comms.lfocus_service",
 						signal_name = "lfocus_signal")
 
-		
-		self.prox_sens_obj = self.bus.get_object("org.freedesktop.Hal",		"/org/freedesktop/Hal/devices/platform_proximity")
-		self.prox_sens_iface = dbus.Interface(self.prox_sens_obj,		"org.freedesktop.Hal.Device")
+
+		self.proximity_obj = self.bus.get_object("org.freedesktop.Hal",	"/org/freedesktop/Hal/devices/platform_proximity")
+		self.proximity_iface = dbus.Interface(self.proximity_obj, 	"org.freedesktop.Hal.Device")
 		self.bus.add_signal_receiver(	self.lfocus_menu_toggle, 
 						signal_name=None, 
 						dbus_interface= 			"org.freedesktop.Hal.Device", 
 						bus_name=				"org.freedesktop.Hal", 
 						path=					"/org/freedesktop/Hal/devices/platform_proximity")
-		
-		self.camera_button_obj = self.bus.get_object("org.freedesktop.Hal",	"/org/freedesktop/Hal/devices/platform_cam_launch")
-		self.camera_button_iface = dbus.Interface(self.camera_button_obj, "org.freedesktop.Hal.Device")
-
 		self.bus.add_signal_receiver(	self.roger2, 
 						signal_name=None, 
 						dbus_interface= "org.freedesktop.Hal.Device", 
 						bus_name="org.freedesktop.Hal", 
 						path="/org/freedesktop/Hal/devices/platform_cam_launch")
-
-
-		
+		self.shutter_button_iface = dbus.Interface(self.shutter_button_obj, 	"org.freedesktop.Hal.Device")
+		'''self.bus.add_signal_receiver(	self.roger, 
+						signal_name=None, 
+						dbus_interface= "org.freedesktop.Hal.Device", 
+						bus_name="org.freedesktop.Hal", 
+						path="/org/freedesktop/Hal/devices/platform_cam_focus")'''
 		self.lfocus_obj= self.bus.get_object("com.nokia.lfocus_comms.lfocus_service","/com/nokia/lfocus_comms/lfocus_service/object")
 		self.button7=gtk.ToggleButton()
 		self.button7.set_active(True)
 		button1 = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,hildon.BUTTON_ARRANGEMENT_VERTICAL)
 		button1.connect("clicked",self.lfocus_menu)
-		button2 = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,hildon.BUTTON_ARRANGEMENT_VERTICAL)
-		button2.connect("clicked",self.changer)
-		image1=gtk.image_new_from_file("/opt/lfocus/lfocus-64.png")
-		container=gtk.Table(1,2,True)
-		button1.add(image1)
 		self.image2=gtk.image_new_from_file("/opt/lfocus/keyoff.png")
-		button2.add(self.image2)
-		container2=gtk.Table(1,2,False)
+		image1=gtk.image_new_from_file("/opt/lfocus/lfocus-64.png")
+		button1.add(image1)
+		container2=gtk.Table(1,1,True)
 		container2.attach(button1,0,1,0,1)
-		container2.attach(button2,1,2,0,1)
+		#container2.attach(button2,1,2,0,1)
 		self.add(container2)
 		self.hide_all()
 	def led_mem(self,stat):
@@ -148,30 +123,28 @@ class lfocusplug(hildondesktop.StatusMenuItem):
 				self.maintimer = gobject.timeout_add(1000, self.led_mem,stat)
 	def signal_filter(self,lfocus_string):
 		global led_vis
-		
-		if lfocus_string=="L1":		
+		if lfocus_string=="L1":
 			if led_vis:
 				if not(self.button3.get_active()):
 					self.button3.set_active(True)
 			else:
 				led(123)
-		if lfocus_string=="L0":		
+		if lfocus_string=="L0":
 			if led_vis:
 				if self.button3.get_active():
 					self.button3.set_active(False)
 			else:
 				led(123)
-		if lfocus_string=="RL1":		
+		if lfocus_string=="RL1":
 			if led_vis:
 				self.button4.set_active(True)
 			else:
 				rled(123)
-		if lfocus_string=="RL0":		
+		if lfocus_string=="RL0":
 			if led_vis:
 				self.button4.set_active(False)
 			else:
 				rled(123)
-
 	def dstr(self,event):
 		global led_vis
 		global menu_vis
@@ -179,18 +152,44 @@ class lfocusplug(hildondesktop.StatusMenuItem):
 		menu_vis=0
 	def lfocus_menu_toggle(self,a,b):
 		if not(self.shutter_button_iface.GetProperty("button.state.value")):
+			
+			global pxs			
 			global menu_vis
 			global led_vis
-			menu_vis+=1
-			if menu_vis == 2:
-				if led_vis:
-					self.dialog1.hide_all()
-					self.dialog1.show_all()
-				else:
-					self.lfocus_menu(123)
-			
-			if menu_vis > 3:
-				menu_vis=4
+			global gr
+			def menu_timer(a,b):
+				if not(self.shutter_button_iface.GetProperty("button.state.value")):
+					global gr,menu_vis
+					if a==gr:
+						if menu_vis==0:
+							if b==1:
+								self.dialog1.hide_all()
+								self.dialog1.show_all()
+							if b==2:
+								self.lfocus_menu(123)
+							menu_vis=1
+			if pxs == 1:
+				print self.proximity_iface.GetProperty("button.state.value")
+				pxs=0
+				#----------------------------------------------------------
+				gr=random.randrange(0,2000)
+				print gr
+				if menu_vis == 0:
+					if led_vis:
+						
+						self.maintimer = gobject.timeout_add(2000,menu_timer,gr,1)
+					else:
+
+						self.maintimer = gobject.timeout_add(2000,menu_timer,gr,2)
+
+
+
+				#----------------------------------------------------------
+			else :
+				pxs+=1
+				if pxs>1:
+					pxs=1
+
 	def ledf(self,*args):
 		stat=int(os.popen("/opt/lfocus/v4l2-ctl -C torch_intensity|awk '{print $2}'").read())
 		if int(stat)==0:
@@ -205,13 +204,14 @@ class lfocusplug(hildondesktop.StatusMenuItem):
 		global menu_vis
 		global mem7_stat
 		global mem8_stat
-		menu_vis=4
-		led_vis=1		
+		#menu_vis=4
+		menu_vis=1
+		led_vis=1
 		self.dialog1=gtk.Dialog("Live Focus")
 		self.dialog1.set_size_request(800,50)
-		self.dialog1.connect("destroy",self.dstr)		
-		contain=gtk.Table(2, 1, False)		
-		table = gtk.Table(3, 3, False)
+		self.dialog1.connect("destroy",self.dstr)
+		contain=gtk.Table(2, 1, False)
+		table = gtk.Table(3, 4, False)
 		table.set_row_spacings(10)
 		image3=gtk.image_new_from_icon_name("gtk-go-down", 50)
 		button2 = gtk.Button()
@@ -225,8 +225,8 @@ class lfocusplug(hildondesktop.StatusMenuItem):
 		def go_down(args):
 			global y_loc
 			y_loc+=70
-			if y_loc>180:
-				y_loc=180
+			if y_loc>250:
+				y_loc=250
 			pannable_area.jump_to(0, y_loc)
 		image3=gtk.image_new_from_icon_name("gtk-go-up", 50)
 		button6 = gtk.Button()
@@ -245,12 +245,23 @@ class lfocusplug(hildondesktop.StatusMenuItem):
 		self.button3.connect("clicked", led)
 		self.button4.connect("clicked", rled)
 		button5.connect("clicked", self.show_diag)
+		global keyboard_stat		
+		if keyboard_stat==0 :
+			self.image2.set_from_file("/opt/lfocus/keyoff.png")
+		else :
+			self.image2.set_from_file("/opt/lfocus/keyon.png")
+		button2_2 = gtk.Button()
+		button2_2.connect("clicked",self.changer)
+		button2_2.add(self.image2)
+		table.attach(button2_2, 0, 1, 0, 1)
 		table.attach(self.button3, 0, 1, 1, 2)
 		table.attach(self.button4, 1, 2, 1, 2)
 		table.attach(button5, 2, 3, 1, 2)
 		self.button6=gtk.ToggleButton("Rem.LED")
 		self.button7=gtk.ToggleButton("Stop RLED")
 		self.button8=gtk.ToggleButton("Timer.RLED")
+
+		
 		table.attach(self.button6, 0, 1, 2, 3)
 		table.attach(self.button7, 1, 2, 2, 3)
 		table.attach(self.button8, 2, 3, 2, 3)
@@ -276,22 +287,28 @@ class lfocusplug(hildondesktop.StatusMenuItem):
 		self.sld = gtk.HScale(props)
 		self.sld.set_digits(0)
 		self.sld.set_value(int(os.popen("/opt/lfocus/v4l2-ctl -C focus_absolute|awk '{print $2}'").read()))
-		self.sld.set_size_request(500,80)
+		#self.sld.set_size_request(500,80)
 		self.sld.set_draw_value(False)
 		self.sld.connect('value-changed', self.set_focus)
-		table.attach(self.sld, 0, 3, 0, 1)
+		table.attach(self.sld, 1, 3, 0, 1)
+		def helper(args):
+			os.popen("dbus-send --print-reply --dest=com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser.open_new_window string:file:///opt/lfocus/help.html &")
+			self.dialog1.hide_all()
+			global menu_vis			
+			menu_vis=0	
+		button9=gtk.Button("Help?")
+		button9.connect("clicked",helper)
+		table.attach(button9,0,3,3,4)
 		pannable_area = hildon.PannableArea()
 		pannable_area.add_with_viewport(table)
 		pannable_area.set_size_request(550,50)
 		contain.attach(button6, 1, 2, 0, 1)
 		contain.attach(button2, 2, 3, 0, 1)
 		contain.attach(pannable_area, 0, 1, 0, 1)
-		
 		self.dialog1.vbox.add(contain)
 		self.dialog1.show_all()
 		global y_loc
 		pannable_area.jump_to(0, y_loc)
-
 	def show_diag(self,*args):
 		def stopwatch(a,b,*args):
 			self.dialog3.hide_all()
@@ -304,7 +321,6 @@ class lfocusplug(hildondesktop.StatusMenuItem):
 					blinker_stat=not(blinker_stat)
 					os.popen("/opt/lfocus/v4l2-ctl -c indicator_intensity="+str(blinker_stat*3))
 				os.popen("sudo lfocus start_capture &")
-
 			def blink(h):
 				global blinker_stat
 				blinker_stat=not(blinker_stat)
@@ -313,16 +329,12 @@ class lfocusplug(hildondesktop.StatusMenuItem):
 					blinker=gobject.timeout_add(1000,blink,h-1)
 					blinker_stat=not(blinker_stat)
 					os.popen("/opt/lfocus/v4l2-ctl -c indicator_intensity="+str(blinker_stat*3))
-			
-
-
 			banner = hildon.hildon_banner_show_information(self.dialog3, "lfocus-64",   "capturing in "+str(b)+" seconds") 
 			if (self.button8.get_active()):
-				blink(b)			
-
+				blink(b)
 			self.maintimer = gobject.timeout_add(1000*b,start_capture)
 		global diag_is_up
-		diag_is_up=1		
+		diag_is_up=1
 		self.dialog3=gtk.Dialog("Stopwatch")
 		self.dialog3.connect("destroy", self.dialog3.hide_all)
 		self.dialog3.set_size_request(800,50)
@@ -344,11 +356,6 @@ class lfocusplug(hildondesktop.StatusMenuItem):
 		table.attach(button20, 0, 1, 0, 1)
 		self.dialog3.vbox.add(table)
 		self.dialog3.show_all()
-	def stop_autofocus(self,a,b):
-		#os.popen("osso-xterm");
-		self.focus_button_iface.SetPropertyBoolean("button.state.value",False)
-		self.focus_button_iface.SetPropertyBoolean("button.state.value",False)
-		self.focus_button_iface.SetPropertyBoolean("button.state.value",False)
 	def shutter_operaion(self,a,b):
 		global keyboard_stat
 		if self.shutter_button_iface.GetProperty("button.state.value"):
@@ -357,16 +364,14 @@ class lfocusplug(hildondesktop.StatusMenuItem):
 				os.popen("sudo lfocus stop &")
 				os.popen("setxkbmap")
 				os.popen("maemo-xinput-sounds &")
-				self.image2.set_from_icon_name("keyoff",50)
+				self.image2.set_from_file("/opt/lfocus/keyoff.png")
 				keyboard_stat=0
 			os.popen("sudo lfocus stop_proximity")
-
 			global menu_vis
 			menu_vis=0
 			self.hide_all()
 			self.dialog1.hide_all()
 			self.dialog2.hide_all()
-
 		else :
 			os.popen("sudo lfocus start_proximity")
 			self.show_all()
